_G.SprintBase = _G.SprintBase or {}

SprintBase.ModPath = ModPath
SprintBase.SavePath = SavePath .. "SprintBaseOptions.txt"
SprintBase.Options = SprintBase.Options or {}
SprintBase.Menu = "SprintBaseMainMenu"

dofile( SprintBase.ModPath .. "lua/options.lua" )
-- dofile( SprintBase.ModPath .. "lua/menus.lua" )

local HookFiles = {

	[ "lib/units/beings/player/states/playerstandard" ] 	= "lua/playerstandard.lua"
	
}

function SprintBase:Save()

	local data = io.open( self.SavePath , "w+" )
	
	if data then
		data:write( json.encode( self.Options ) )
		data:close()
	end
	
end

function SprintBase:Load()

	local data = io.open( self.SavePath , "r" )
	
	if data then
		self.Options = json.decode( data:read( "*all" ) )
		data:close()
	end
	
end

function SprintBase:DefaultSettings()

	for k , v in pairs( SprintBase.MenuOptions.Toggle ) do
		if self:HasSetting( k ) == nil then SprintBase.Options[ k ] = v[ 4 ] end
	end
	
	self:Save()

end

function SprintBase:HasSetting( s )

	return SprintBase.Options[ s ]
	
end

SprintBase:Load()
SprintBase:DefaultSettings()

function SprintBase:MeleeType( m )

	for k , v in ipairs( SprintBase.BluntWeapons ) do
		if m == v then return "Blunt" end
	end
	for k , v in ipairs( SprintBase.SmallBladedWeapons ) do
		if m == v then return "SmallBladed" end
	end
	return "LargeBladed"

end

Hooks:Add( "MenuManagerSetupCustomMenus" , "SprintBaseMenuManagerPostSetupCustomMenus" , function( self , nodes )
    
	MenuHelper:NewMenu( SprintBase.Menu )
	
	for k , v in pairs( SprintBase.MenuOptions.Menu ) do
		MenuHelper:NewMenu( k )
	end
	
end )

Hooks:Add( "LocalizationManagerPostInit" , "SprintBaseLocalizationManagerPostInit" , function( self )

	self:load_localization_file( SprintBase.ModPath .. "loc/english.txt" )
	
	for _ , file in pairs( file.GetFiles( SprintBase.ModPath .. "loc/" ) ) do
		local loc = file:match( '^(.*).txt$' )
		
		if loc and Idstring( loc ) and Idstring( loc ):key() == SystemInfo:language():key() then
			self:load_localization_file( SprintBase.ModPath .. "loc/" .. file )
		end
	end

end )

Hooks:Add( "MenuManagerBuildCustomMenus" , "SprintBaseMenuManagerPostBuildCustomMenus" , function( self , nodes )
	
	nodes[ SprintBase.Menu ] = MenuHelper:BuildMenu( SprintBase.Menu , { focus_changed_callback = "SprintBaseMenuMOTDFocus" } )
    MenuHelper:AddMenuItem( nodes["blt_options"] , SprintBase.Menu , "sprint_options_menu_title" , "sprint_options_menu_desc" )
	
	for k , v in pairs( SprintBase.MenuOptions.Menu ) do	
		nodes[ k ] = MenuHelper:BuildMenu( k , v[ 4 ] )
		MenuHelper:AddMenuItem( nodes[ SprintBase.Menu ] , k , v[ 1 ] , v[ 2 ] , v[ 3 ] )
	end
	
end )

Hooks:Add( "MenuManagerPopulateCustomMenus" , "SprintBaseMenuManagerPostPopulateCustomMenus" , function( self , nodes )

	MenuCallbackHandler.SprintBaseMainMenuButtonCallback = function( self ) end
	
	MenuHelper:AddButton({
		id 			= "SprintBaseMainMenuButton",
		title 		= "",
		desc 		= "",
		callback 	= "SprintBaseMainMenuButtonCallback",
		menu_id 	= "SprintBaseMainMenu",
		localized 	= false
	})
	
	for k , v in pairs( SprintBase.MenuOptions.Toggle ) do
	
		MenuCallbackHandler[ k .. "Toggle" ] = function( self , item )
			SprintBase.Options[ k ] = item:value() == "on" or false
			SprintBase:Save()
		end
		
		MenuHelper:AddToggle({
			id 			= "ID" .. k .. "Toggle",
			title 		= v[ 2 ],
			desc 		= v[ 3 ],
			callback 	= k .. "Toggle",
			menu_id 	= v[ 1 ],
			value 		= SprintBase.Options[ k ]
		})
		
	end

end )

if RequiredScript then

	local requiredScript = RequiredScript:lower()
	
	if HookFiles[ requiredScript ] then
		dofile( SprintBase.ModPath .. HookFiles[ requiredScript ] )
	end
	
end